"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const typescript_rest_1 = require("typescript-rest");
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
/**
 * JWT-checking decorator to be used with typescript-rest as annotation.
 */
function JwtGuard(_target, _key, descriptor) {
    const original = descriptor.value;
    // eslint-disable-next-line
    descriptor.value = function (context, ...args) {
        const accessToken = context.request.cookies['BEARER'];
        if (!accessToken) {
            throw new typescript_rest_1.Errors.UnauthorizedError('No access token provided.');
        }
        try {
            jsonwebtoken_1.default.verify(accessToken, process.env.SECRET);
        }
        catch (error) {
            throw new typescript_rest_1.Errors.ForbiddenError('Invalid or expired JWT provided.');
        }
        return original.apply(this, args);
    };
}
exports.default = JwtGuard;
//# sourceMappingURL=index.js.map